@@ -50,10 +50,10 @@ class notion_connector:
 ###################################
 # Créateur de .json avec de la data
 ###################################
-	def put_in_file(self, data, **kwargs):
+	def put_in_file(self, data, *args):
 		to_write = json.dumps(data, indent=4, sort_keys=True)
-		if 'name' in kwargs:
-			name = 'notion_' + kwargs['name']
+		if len(args) > 0:
+			name = 'notion_' + args[0]
 		else:
 			name = 'notion_output.json'
 		if os.path.exists(name):
@@ -106,7 +106,7 @@ class notion_connector:
 				if end_reply['next_cursor'] is None:
 					break
 		except requests.exceptions.HTTPError as err:
-			self.put_in_file(json.loads(reply.text), name='error.json')
+			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
 		ret = []
 		for line in data:
@@ -133,19 +133,20 @@ class notion_connector:
 		data = {'properties': {}}
 		i = False
 		for i in properties.items():
-			if i == None:
+			if self.updateProperties(i[1]) == None:
 				continue
 			data['properties'][i[0]] = self.updateProperties(i[1])
 			i = True
 		if i == False:
 			return
+		self.put_in_file(data, 'data.json')
 		url = self.url + '/pages/' + pageId
 		try :
 			reply = requests.patch(url, headers=self.head, data=json.dumps(data))
 			reply.raise_for_status()
 			print(self.GREEN + "[NOTION CONNECTOR] Success PATCH on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
-			self.put_in_file(json.loads(reply.text), name='error.json')
+			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on PATCH ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
@@ -171,7 +172,7 @@ class notion_connector:
 			if self.verbose == True:
 				print(self.GREEN + "[NOTION CONNECTOR] Success PATCH on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
-			self.put_in_file(json.loads(reply.text), name='error.json')
+			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on PATCH ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
@@ -201,7 +202,7 @@ class notion_connector:
 			if self.verbose == True:
 				print(self.GREEN + "[NOTION CONNECTOR] Success POST on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
-			self.put_in_file(json.loads(reply.text), name='error.json')
+			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + ' on POST ' + url + self.DEFAULT)
 		return (json.loads(reply.text))
 
@@ -237,7 +238,7 @@ class notion_connector:
 			if self.verbose == True:
 				print(self.GREEN + "[NOTION CONNECTOR] Success POST on " + url + self.DEFAULT)
 		except requests.exceptions.HTTPError as err:
-			self.put_in_file(json.loads(reply.text), name='error.json')
+			self.put_in_file(json.loads(reply.text), 'error.json')
 			print(self.RED + '[NOTION CONNECTOR] ' + str(err) + 'on GET ' + url + self.DEFAULT)
 		return (ret)
 
